"""Top-level package for glacier-flow-model."""
from glacier_flow_model.data import PkgDataAccess
from glacier_flow_model.model import GlacierFlowModel

__all__ = ["GlacierFlowModel", "PkgDataAccess"]
